==> fred_diagonal-0.2.0-py3-none-any.whl: diagonal/client.py <==
"""Diagnostics client."""
from enum import Enum, unique
from typing import Dict, Optional, cast

import fred_api.diagnostics.service_diagnostics_grpc_pb2_grpc
from fred_api.diagnostics.service_diagnostics_grpc_pb2 import StatusReply
from frgal import GrpcDecoder
from frgal.aio import AsyncGrpcClient
from google.protobuf.empty_pb2 import Empty
from pydantic import BaseModel


@unique
class Status(str, Enum):
    """Service status code."""

    UNKNOWN = "unknown"
    OK = "ok"
    WARNING = "warning"
    ERROR = "error"


class About(BaseModel):
    """Information about server and API versions."""

    server_version: str
    api_versions: Dict[str, str]


class Service(BaseModel):
    """Service status information."""

    status: Status
    note: Optional[str] = None
    extras: Dict[str, str] = {}


class DiagnosticsDecoder(GrpcDecoder):
    """Diagnostics service decoder."""

    STATUS_CODE_ENUM = {
        0: Status.UNKNOWN,
        1: Status.OK,
        2: Status.WARNING,
        3: Status.ERROR,
    }

    def __init__(self) -> None:
        super().__init__()
        self.set_decoder(StatusReply.Data.Service, self._decode_service)

    def _decode_service(self, value: StatusReply.Data.Service) -> Service:
        """Decode service status information."""
        return Service(
            status=self.STATUS_CODE_ENUM[value.status],
            note=self.decode(value.note),
            extras=self.decode(value.extras),
        )


class DiagnosticsClient(AsyncGrpcClient):
    """Diagnostics service gRPC client."""

    service = "Diagnostics"
    decoder_cls = DiagnosticsDecoder
    grpc_modules = (fred_api.diagnostics.service_diagnostics_grpc_pb2_grpc,)

    async def about(self) -> About:
        """Return information about server and API versions."""
        result = await self.call(self.service, "about", Empty())
        return About(**result)

    async def status(self) -> Dict[str, Service]:
        """Return service status information for all available services."""
        result = await self.call(self.service, "status", Empty())
        return cast(Dict[str, Service], result)

==> fred_diagonal-1.1.0-py3-none-any.whl: diagonal/client.py <==
"""Diagnostics client."""

from enum import Enum, unique
from typing import Dict, Optional, cast

import fred_api.diagnostics.service_diagnostics_grpc_pb2_grpc
from fred_api.diagnostics.service_diagnostics_grpc_pb2 import StatusReply
from fred_types import BaseModel
from frgal import GrpcDecoder
from frgal.aio import AsyncGrpcClient
from google.protobuf.empty_pb2 import Empty

from ._utils import catch_errors


@unique
class Status(str, Enum):
    """Service status code."""

    UNKNOWN = "unknown"
    OK = "ok"
    WARNING = "warning"
    ERROR = "error"


class About(BaseModel):
    """Information about server and API versions."""

    server_version: str
    api_versions: Dict[str, str]


class Service(BaseModel):
    """Service status information."""

    status: Status
    note: Optional[str] = None
    extras: Dict[str, str] = {}


class DiagnosticsDecoder(GrpcDecoder):
    """Diagnostics service decoder."""

    STATUS_CODE_ENUM = {
        0: Status.UNKNOWN,
        1: Status.OK,
        2: Status.WARNING,
        3: Status.ERROR,
    }

    def __init__(self) -> None:
        super().__init__()
        self.set_decoder(StatusReply.Data.Service, self._decode_service)

    def _decode_service(self, value: StatusReply.Data.Service) -> Service:
        """Decode service status information."""
        return Service(
            status=self.STATUS_CODE_ENUM[value.status],
            note=self.decode(value.note),
            extras=self.decode(value.extras),
        )


class DiagnosticsClient(AsyncGrpcClient):
    """Diagnostics service gRPC client."""

    service = "Diagnostics"
    decoder_cls = DiagnosticsDecoder
    grpc_modules = (fred_api.diagnostics.service_diagnostics_grpc_pb2_grpc,)

    @catch_errors
    async def about(self) -> About:
        """Return information about server and API versions.

        Raises:
            DiagnosticsNotImplemented: If diagnostics service is not implemented
                on the server.
            ServiceUnavailable: If connection to the service failed.
            DiagnosticsError: If there has been any other problem with the response.
        """
        result = await self.call(self.service, "about", Empty())
        return About(**result or {})

    @catch_errors
    async def status(self) -> Dict[str, Service]:
        """Return service status information for all available services.

        Raises:
            DiagnosticsNotImplemented: If diagnostics service is not implemented
                on the server.
            ServiceUnavailable: If connection to the service failed.
            DiagnosticsError: If there has been any other problem with the response.
        """
        result = await self.call(self.service, "status", Empty())
        return cast(Dict[str, Service], result or {})
